# OE1100
###############################################################################################################################
# Add a button over the default POST button.
# When clicked by the user, 
###############################################################################################################################
# Copyright 2020 Orchid Systems 
# -----------------------------
# Permitted for use with Orchid Systems Modules only.
# The code is supplied on an "as is" basis for training and demonstration purposes only and is not supported by Orchid Systems.
# If this code is deployed in a live production environment it is the responsibility of the End User to ensure 
# that it is operating as required.
###############################################################################################################################
from accpac import *

def main(args):
	MyUI()

class MyUI(UI):
	def __init__(self):
		UI.__init__(self)
		self.createScreen()

	def createScreen(self):
		self.getControlInfo("form|APP_Save_Button", self.onControlInfo)
		self.show()

	def onControlInfo(self, info):
		f = info.find("form")
		b = info.find("APP_Save_Button")

		ctrl = self.addButton("btnMyPost", "Post")
		ctrl.height = b.height
		ctrl.left = b.left
		ctrl.top = b.top - f.height
		ctrl.width = b.width
		ctrl.disable()
		self.btnMyPost = ctrl
		ctrl.onClick = self.btnMyPost_Click

		self.dsH = self.openDataSource("adsOEORDH")
		self.dsD = self.openDataSource("adsOEORDD")
		self.dsH.onAfter = self.dsH_onAfter

		# Set the caption on PO number to include the (*) to denote it as mandatory.
		self.getHostControl("afeOEORDHponumber1").setCaption("PO No.*")
		
		self.show()

	def dsH_onAfter(self, eventName, fieldName, value):
		if eventName == "FETCH" or eventName.startswith("GO") or eventName == "READ": # or eventName == "OPEN":
			self.btnMyPost.enable()
		if eventName == "INIT":
			self.btnMyPost.disable()
		if eventName == "PUT" and fieldName == "CUSTOMER":
			self.btnMyPost.enable()

	def btnMyPost_Click(self):
		if self.ValidateMandatoryFields() == True:
			self.getHostControl("APP_Save_Button").click()
			self.getHostControl("avlOEORDDdetail1").refreshData()

	def ValidateMandatoryFields(self):
		# check if mandatory fields are filled in.

		bValid = True
		
		# PO Number field:
		ponumber = self.dsH.get("PONUMBER").strip()
		if ponumber == "":
			showMessageBox("PO Number field must be filled in.")
			bValid = False
		
		return bValid
		
